@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2010-2013  Tetsuo Handa <penguin-kernel@I-love.SAKURA.ne.jp>
  *
- * Version: 0.1.17   2016/09/28
+ * Version: 0.2   2016/10/05
  */
 
 #include "caitsith.h"
@@ -40,6 +40,8 @@ struct caitsith_exports caitsith_exports;
 /* Function pointers originally registered by register_security(). */
 static struct security_operations original_security_ops /* = *security_ops; */;
 
+#define wait_ready(op) while (!original_security_ops.op)
+
 #if !defined(CONFIG_CAITSITH_DEBUG)
 #define cs_debug_trace(pos) do { } while (0)
 #else
@@ -65,6 +67,7 @@ static struct security_operations original_security_ops /* = *security_ops; */;
 static void cs_clear_execve(int ret, struct cs_security *security)
 {
 	struct cs_request_info *r;
+
 	if (security == &cs_default_security || security == &cs_oom_security)
 		return;
 	r = security->r;
@@ -86,6 +89,7 @@ static void cs_add_task_security(struct cs_security *ptr,
 				 struct list_head *list)
 {
 	unsigned long flags;
+
 	spin_lock_irqsave(&cs_task_security_list_lock, flags);
 	list_add_rcu(&ptr->list, list);
 	spin_unlock_irqrestore(&cs_task_security_list_lock, flags);
@@ -133,7 +137,8 @@ struct cs_security *cs_find_task_security(const struct task_struct *task)
 	struct list_head *list = &cs_task_security_list
 		[hash_ptr((void *) task, CS_TASK_SECURITY_HASH_BITS)];
 	/* Make sure INIT_LIST_HEAD() in cs_mm_init() takes effect. */
-	while (!list->next);
+	while (!list->next)
+		;
 	rcu_read_lock();
 	list_for_each_entry_rcu(ptr, list, list) {
 		if (ptr->task != task)
@@ -168,6 +173,7 @@ struct cs_security *cs_find_task_security(const struct task_struct *task)
 static void cs_rcu_free(struct rcu_head *rcu)
 {
 	struct cs_security *ptr = container_of(rcu, typeof(*ptr), rcu);
+
 	kfree(ptr);
 }
 
@@ -182,6 +188,7 @@ static void cs_free_task_security(const struct task_struct *task)
 {
 	unsigned long flags;
 	struct cs_security *ptr = cs_find_task_security(task);
+
 	if (ptr == &cs_default_security || ptr == &cs_oom_security)
 		return;
 	spin_lock_irqsave(&cs_task_security_list_lock, flags);
@@ -200,9 +207,10 @@ static void cs_free_task_security(const struct task_struct *task)
 static int cs_task_alloc_security(struct task_struct *p)
 {
 	int rc = cs_alloc_task_security(p);
+
 	if (rc)
 		return rc;
-	while (!original_security_ops.task_alloc_security);
+	wait_ready(task_alloc_security);
 	rc = original_security_ops.task_alloc_security(p);
 	if (rc)
 		cs_free_task_security(p);
@@ -218,7 +226,7 @@ static int cs_task_alloc_security(struct task_struct *p)
  */
 static void cs_task_free_security(struct task_struct *p)
 {
-	while (!original_security_ops.task_free_security);
+	wait_ready(task_free_security);
 	original_security_ops.task_free_security(p);
 	cs_free_task_security(p);
 }
@@ -233,7 +241,8 @@ static void cs_task_free_security(struct task_struct *p)
 static int cs_bprm_alloc_security(struct linux_binprm *bprm)
 {
 	int rc;
-	while (!original_security_ops.bprm_alloc_security);
+
+	wait_ready(bprm_alloc_security);
 	rc = original_security_ops.bprm_alloc_security(bprm);
 	if (bprm->security || rc)
 		return rc;
@@ -274,7 +283,7 @@ static void cs_bprm_free_security(struct linux_binprm *bprm)
 	 * at &cs_bprm_security .
 	 */
 	if (bprm->security != &cs_bprm_security) {
-		while (!original_security_ops.bprm_free_security);
+		wait_ready(bprm_free_security);
 		original_security_ops.bprm_free_security(bprm);
 	}
 	/*
@@ -298,7 +307,7 @@ static void cs_bprm_apply_creds(struct linux_binprm *bprm, int unsafe)
 {
 	if (bprm->security == &cs_bprm_security)
 		bprm->security = NULL;
-	while (!original_security_ops.bprm_apply_creds);
+	wait_ready(bprm_apply_creds);
 	original_security_ops.bprm_apply_creds(bprm, unsafe);
 	cs_clear_execve(0, cs_current_security());
 }
@@ -314,6 +323,7 @@ static _Bool cs_policy_loader_exists(void)
 {
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 28)
 	struct path path;
+
 	if (kern_path(CONFIG_CAITSITH_POLICY_LOADER, LOOKUP_FOLLOW, &path)
 	    == 0) {
 		path_put(&path);
@@ -321,6 +331,7 @@ static _Bool cs_policy_loader_exists(void)
 	}
 #else
 	struct nameidata nd;
+
 	if (path_lookup(CONFIG_CAITSITH_POLICY_LOADER, LOOKUP_FOLLOW, &nd)
 	    == 0) {
 		path_put(&nd.path);
@@ -343,11 +354,12 @@ static _Bool cs_policy_loader_exists(void)
  * invoke /sbin/caitsith-init and wait for the termination of
  * /sbin/caitsith-init and then continues invocation of /sbin/init.
  * /sbin/caitsith-init reads policy files in /etc/caitsith/ directory and
- * writes to /proc/caitsith/ interfaces.
+ * writes to /sys/kernel/security/caitsith/ interfaces.
  */
 static void cs_load_policy(const char *filename)
 {
 	static _Bool done;
+
 	if (done)
 		return;
 	if (strcmp(filename, CONFIG_CAITSITH_ACTIVATION_TRIGGER))
@@ -358,6 +370,7 @@ static void cs_load_policy(const char *filename)
 	{
 		char *argv[2];
 		char *envp[3];
+
 		printk(KERN_INFO "Calling %s to load policy. Please wait.\n",
 		       CONFIG_CAITSITH_POLICY_LOADER);
 		argv[0] = (char *) CONFIG_CAITSITH_POLICY_LOADER;
@@ -382,6 +395,7 @@ static void cs_load_policy(const char *filename)
 static int cs_bprm_check_security(struct linux_binprm *bprm)
 {
 	struct cs_security *security = cs_current_security();
+
 	if (security == &cs_default_security || security == &cs_oom_security)
 		return -ENOMEM;
 	if (!security->r) {
@@ -394,7 +408,7 @@ static int cs_bprm_check_security(struct linux_binprm *bprm)
 		if (rc)
 			return rc;
 	}
-	while (!original_security_ops.bprm_check_security);
+	wait_ready(bprm_check_security);
 	return original_security_ops.bprm_check_security(bprm);
 }
 
@@ -420,9 +434,10 @@ static int cs_open(struct file *f)
 static int cs_dentry_open(struct file *f)
 {
 	int rc = cs_open(f);
+
 	if (rc)
 		return rc;
-	while (!original_security_ops.dentry_open);
+	wait_ready(dentry_open);
 	return original_security_ops.dentry_open(f);
 }
 
@@ -440,6 +455,7 @@ static int cs_inode_setattr(struct dentry *dentry, struct vfsmount *mnt,
 {
 	int rc = 0;
 	struct path path = { .mnt = mnt, .dentry = dentry };
+
 	if (attr->ia_valid & ATTR_UID)
 		rc = cs_chown_permission(&path, attr->ia_uid, -1);
 	if (!rc && (attr->ia_valid & ATTR_GID))
@@ -450,7 +466,7 @@ static int cs_inode_setattr(struct dentry *dentry, struct vfsmount *mnt,
 		rc = cs_truncate_permission(&path);
 	if (rc)
 		return rc;
-	while (!original_security_ops.inode_setattr);
+	wait_ready(inode_setattr);
 	return original_security_ops.inode_setattr(dentry, mnt, attr);
 }
 
@@ -466,9 +482,10 @@ static int cs_inode_getattr(struct vfsmount *mnt, struct dentry *dentry)
 {
 	struct path path = { .mnt = mnt, .dentry = dentry };
 	int rc = cs_getattr_permission(&path);
+
 	if (rc)
 		return rc;
-	while (!original_security_ops.inode_getattr);
+	wait_ready(inode_getattr);
 	return original_security_ops.inode_getattr(mnt, dentry);
 }
 
@@ -488,9 +505,10 @@ static int cs_inode_mknod(struct inode *dir, struct dentry *dentry,
 {
 	struct path path = { .mnt = mnt, .dentry = dentry };
 	int rc = cs_mknod_permission(&path, mode, dev);
+
 	if (rc)
 		return rc;
-	while (!original_security_ops.inode_mknod);
+	wait_ready(inode_mknod);
 	return original_security_ops.inode_mknod(dir, dentry, mnt, mode, dev);
 }
 
@@ -509,9 +527,10 @@ static int cs_inode_mkdir(struct inode *dir, struct dentry *dentry,
 {
 	struct path path = { .mnt = mnt, .dentry = dentry };
 	int rc = cs_mkdir_permission(&path, mode);
+
 	if (rc)
 		return rc;
-	while (!original_security_ops.inode_mkdir);
+	wait_ready(inode_mkdir);
 	return original_security_ops.inode_mkdir(dir, dentry, mnt, mode);
 }
 
@@ -529,9 +548,10 @@ static int cs_inode_rmdir(struct inode *dir, struct dentry *dentry,
 {
 	struct path path = { .mnt = mnt, .dentry = dentry };
 	int rc = cs_rmdir_permission(&path);
+
 	if (rc)
 		return rc;
-	while (!original_security_ops.inode_rmdir);
+	wait_ready(inode_rmdir);
 	return original_security_ops.inode_rmdir(dir, dentry, mnt);
 }
 
@@ -549,9 +569,10 @@ static int cs_inode_unlink(struct inode *dir, struct dentry *dentry,
 {
 	struct path path = { .mnt = mnt, .dentry = dentry };
 	int rc = cs_unlink_permission(&path);
+
 	if (rc)
 		return rc;
-	while (!original_security_ops.inode_unlink);
+	wait_ready(inode_unlink);
 	return original_security_ops.inode_unlink(dir, dentry, mnt);
 }
 
@@ -570,9 +591,10 @@ static int cs_inode_symlink(struct inode *dir, struct dentry *dentry,
 {
 	struct path path = { .mnt = mnt, .dentry = dentry };
 	int rc = cs_symlink_permission(&path, old_name);
+
 	if (rc)
 		return rc;
-	while (!original_security_ops.inode_symlink);
+	wait_ready(inode_symlink);
 	return original_security_ops.inode_symlink(dir, dentry, mnt, old_name);
 }
 
@@ -596,9 +618,10 @@ static int cs_inode_rename(struct inode *old_dir, struct dentry *old_dentry,
 	struct path old = { .mnt = old_mnt, .dentry = old_dentry };
 	struct path new = { .mnt = new_mnt, .dentry = new_dentry };
 	int rc = cs_rename_permission(&old, &new);
+
 	if (rc)
 		return rc;
-	while (!original_security_ops.inode_rename);
+	wait_ready(inode_rename);
 	return original_security_ops.inode_rename(old_dir, old_dentry, old_mnt,
 						  new_dir, new_dentry,
 						  new_mnt);
@@ -622,9 +645,10 @@ static int cs_inode_link(struct dentry *old_dentry, struct vfsmount *old_mnt,
 	struct path old = { .mnt = old_mnt, .dentry = old_dentry };
 	struct path new = { .mnt = new_mnt, .dentry = new_dentry };
 	int rc = cs_link_permission(&old, &new);
+
 	if (rc)
 		return rc;
-	while (!original_security_ops.inode_link);
+	wait_ready(inode_link);
 	return original_security_ops.inode_link(old_dentry, old_mnt, dir,
 						new_dentry, new_mnt);
 }
@@ -644,9 +668,10 @@ static int cs_inode_create(struct inode *dir, struct dentry *dentry,
 {
 	struct path path = { .mnt = mnt, .dentry = dentry };
 	int rc = cs_mknod_permission(&path, mode, 0);
+
 	if (rc)
 		return rc;
-	while (!original_security_ops.inode_create);
+	wait_ready(inode_create);
 	return original_security_ops.inode_create(dir, dentry, mnt, mode);
 }
 
@@ -682,6 +707,7 @@ static DEFINE_SPINLOCK(cs_accepted_socket_list_lock);
 static void cs_socket_rcu_free(struct rcu_head *rcu)
 {
 	struct cs_socket_tag *ptr = container_of(rcu, typeof(*ptr), rcu);
+
 	kfree(ptr);
 }
 
@@ -731,6 +757,7 @@ static int cs_validate_socket(struct socket *sock)
 	struct inode *inode = SOCK_INODE(sock);
 	struct cs_socket_tag *ptr;
 	int ret = 0;
+
 	rcu_read_lock();
 	list_for_each_entry_rcu(ptr, &cs_accepted_socket_list, list) {
 		if (ptr->inode != inode)
@@ -789,12 +816,13 @@ static int cs_socket_accept(struct socket *sock, struct socket *newsock)
 {
 	struct cs_socket_tag *ptr;
 	int rc = cs_validate_socket(sock);
+
 	if (rc < 0)
 		return rc;
 	ptr = kzalloc(sizeof(*ptr), GFP_KERNEL);
 	if (!ptr)
 		return -ENOMEM;
-	while (!original_security_ops.socket_accept);
+	wait_ready(socket_accept);
 	rc = original_security_ops.socket_accept(sock, newsock);
 	if (rc) {
 		kfree(ptr);
@@ -825,12 +853,13 @@ static int cs_socket_accept(struct socket *sock, struct socket *newsock)
 static int cs_socket_listen(struct socket *sock, int backlog)
 {
 	int rc = cs_validate_socket(sock);
+
 	if (rc < 0)
 		return rc;
 	rc = cs_socket_listen_permission(sock);
 	if (rc)
 		return rc;
-	while (!original_security_ops.socket_listen);
+	wait_ready(socket_listen);
 	return original_security_ops.socket_listen(sock, backlog);
 }
 
@@ -847,12 +876,13 @@ static int cs_socket_connect(struct socket *sock, struct sockaddr *addr,
 			     int addr_len)
 {
 	int rc = cs_validate_socket(sock);
+
 	if (rc < 0)
 		return rc;
 	rc = cs_socket_connect_permission(sock, addr, addr_len);
 	if (rc)
 		return rc;
-	while (!original_security_ops.socket_connect);
+	wait_ready(socket_connect);
 	return original_security_ops.socket_connect(sock, addr, addr_len);
 }
 
@@ -869,12 +899,13 @@ static int cs_socket_bind(struct socket *sock, struct sockaddr *addr,
 			  int addr_len)
 {
 	int rc = cs_validate_socket(sock);
+
 	if (rc < 0)
 		return rc;
 	rc = cs_socket_bind_permission(sock, addr, addr_len);
 	if (rc)
 		return rc;
-	while (!original_security_ops.socket_bind);
+	wait_ready(socket_bind);
 	return original_security_ops.socket_bind(sock, addr, addr_len);
 }
 
@@ -891,12 +922,13 @@ static int cs_socket_sendmsg(struct socket *sock, struct msghdr *msg,
 			     int size)
 {
 	int rc = cs_validate_socket(sock);
+
 	if (rc < 0)
 		return rc;
 	rc = cs_socket_sendmsg_permission(sock, msg, size);
 	if (rc)
 		return rc;
-	while (!original_security_ops.socket_sendmsg);
+	wait_ready(socket_sendmsg);
 	return original_security_ops.socket_sendmsg(sock, msg, size);
 }
 
@@ -914,9 +946,10 @@ static int cs_socket_recvmsg(struct socket *sock, struct msghdr *msg,
 			     int size, int flags)
 {
 	int rc = cs_validate_socket(sock);
+
 	if (rc < 0)
 		return rc;
-	while (!original_security_ops.socket_recvmsg);
+	wait_ready(socket_recvmsg);
 	return original_security_ops.socket_recvmsg(sock, msg, size, flags);
 }
 
@@ -930,9 +963,10 @@ static int cs_socket_recvmsg(struct socket *sock, struct msghdr *msg,
 static int cs_socket_getsockname(struct socket *sock)
 {
 	int rc = cs_validate_socket(sock);
+
 	if (rc < 0)
 		return rc;
-	while (!original_security_ops.socket_getsockname);
+	wait_ready(socket_getsockname);
 	return original_security_ops.socket_getsockname(sock);
 }
 
@@ -946,9 +980,10 @@ static int cs_socket_getsockname(struct socket *sock)
 static int cs_socket_getpeername(struct socket *sock)
 {
 	int rc = cs_validate_socket(sock);
+
 	if (rc < 0)
 		return rc;
-	while (!original_security_ops.socket_getpeername);
+	wait_ready(socket_getpeername);
 	return original_security_ops.socket_getpeername(sock);
 }
 
@@ -964,9 +999,10 @@ static int cs_socket_getpeername(struct socket *sock)
 static int cs_socket_getsockopt(struct socket *sock, int level, int optname)
 {
 	int rc = cs_validate_socket(sock);
+
 	if (rc < 0)
 		return rc;
-	while (!original_security_ops.socket_getsockopt);
+	wait_ready(socket_getsockopt);
 	return original_security_ops.socket_getsockopt(sock, level, optname);
 }
 
@@ -982,9 +1018,10 @@ static int cs_socket_getsockopt(struct socket *sock, int level, int optname)
 static int cs_socket_setsockopt(struct socket *sock, int level, int optname)
 {
 	int rc = cs_validate_socket(sock);
+
 	if (rc < 0)
 		return rc;
-	while (!original_security_ops.socket_setsockopt);
+	wait_ready(socket_setsockopt);
 	return original_security_ops.socket_setsockopt(sock, level, optname);
 }
 
@@ -999,9 +1036,10 @@ static int cs_socket_setsockopt(struct socket *sock, int level, int optname)
 static int cs_socket_shutdown(struct socket *sock, int how)
 {
 	int rc = cs_validate_socket(sock);
+
 	if (rc < 0)
 		return rc;
-	while (!original_security_ops.socket_shutdown);
+	wait_ready(socket_shutdown);
 	return original_security_ops.socket_shutdown(sock, how);
 }
 
@@ -1018,7 +1056,7 @@ static int cs_socket_shutdown(struct socket *sock, int how)
  */
 static void cs_inode_free_security(struct inode *inode)
 {
-	while (!original_security_ops.inode_free_security);
+	wait_ready(inode_free_security);
 	original_security_ops.inode_free_security(inode);
 	if (inode->i_sb && inode->i_sb->s_magic == SOCKFS_MAGIC)
 		cs_update_socket_tag(inode, 0);
@@ -1037,9 +1075,10 @@ static void cs_inode_free_security(struct inode *inode)
 static int cs_sb_pivotroot(struct path *old_path, struct path *new_path)
 {
 	int rc = cs_pivot_root_permission(old_path, new_path);
+
 	if (rc)
 		return rc;
-	while (!original_security_ops.sb_pivotroot);
+	wait_ready(sb_pivotroot);
 	return original_security_ops.sb_pivotroot(old_path, new_path);
 }
 
@@ -1058,9 +1097,10 @@ static int cs_sb_mount(char *dev_name, struct path *path, char *type,
 		       unsigned long flags, void *data_page)
 {
 	int rc = cs_mount_permission(dev_name, path, type, flags, data_page);
+
 	if (rc)
 		return rc;
-	while (!original_security_ops.sb_mount);
+	wait_ready(sb_mount);
 	return original_security_ops.sb_mount(dev_name, path, type, flags,
 					      data_page);
 }
@@ -1077,9 +1117,10 @@ static int cs_sb_umount(struct vfsmount *mnt, int flags)
 {
 	struct path path = { .mnt = mnt, .dentry = mnt->mnt_root };
 	int rc = cs_umount_permission(&path, flags);
+
 	if (rc)
 		return rc;
-	while (!original_security_ops.sb_umount);
+	wait_ready(sb_umount);
 	return original_security_ops.sb_umount(mnt, flags);
 }
 
@@ -1096,9 +1137,10 @@ static int cs_file_fcntl(struct file *file, unsigned int cmd,
 			 unsigned long arg)
 {
 	int rc = cs_fcntl_permission(file, cmd, arg);
+
 	if (rc)
 		return rc;
-	while (!original_security_ops.file_fcntl);
+	wait_ready(file_fcntl);
 	return original_security_ops.file_fcntl(file, cmd, arg);
 }
 
@@ -1115,9 +1157,10 @@ static int cs_file_ioctl(struct file *filp, unsigned int cmd,
 			 unsigned long arg)
 {
 	int rc = cs_ioctl_permission(filp, cmd, arg);
+
 	if (rc)
 		return rc;
-	while (!original_security_ops.file_ioctl);
+	wait_ready(file_ioctl);
 	return original_security_ops.file_ioctl(filp, cmd, arg);
 }
 
@@ -1137,6 +1180,7 @@ static int cs_file_ioctl(struct file *filp, unsigned int cmd,
 static int cs_prepend(char **buffer, int *buflen, const char *str)
 {
 	int namelen = strlen(str);
+
 	if (*buflen < namelen)
 		return -ENOMEM;
 	*buflen -= namelen;
@@ -1159,7 +1203,8 @@ static int cs_sysctl(struct ctl_table *table, int op)
 	struct cs_path_info buf;
 	int buflen;
 	char *buffer;
-	while (!original_security_ops.sysctl);
+
+	wait_ready(sysctl);
 	error = original_security_ops.sysctl(table, op);
 	if (error)
 		return error;
@@ -1178,6 +1223,7 @@ static int cs_sysctl(struct ctl_table *table, int op)
 		while (table) {
 			char num[32];
 			const char *sp = table->procname;
+
 			if (!sp) {
 				memset(num, 0, sizeof(num));
 				snprintf(num, sizeof(num) - 1, "=%d=",
@@ -1217,7 +1263,7 @@ out:
  * Thus, modifying original_security_ops.op has to be atomic.
  */
 #define swap_security_ops(op)						\
-	original_security_ops.op = ops->op; smp_wmb(); ops->op = cs_##op;
+	original_security_ops.op = ops->op; smp_wmb(); ops->op = cs_##op
 
 /**
  * cs_update_security_ops - Overwrite original "struct security_operations".
@@ -1282,6 +1328,7 @@ static void __init cs_update_security_ops(struct security_operations *ops)
 static int __init cs_init(void)
 {
 	struct security_operations *ops = probe_security_ops();
+
 	if (!ops)
 		goto out;
 	caitsith_exports.find_task_by_vpid = probe_find_task_by_vpid();
@@ -1298,6 +1345,7 @@ static int __init cs_init(void)
 		goto out;
 	{
 		int idx;
+
 		for (idx = 0; idx < CS_MAX_TASK_SECURITY_HASH; idx++)
 			INIT_LIST_HEAD(&cs_task_security_list[idx]);
 	}
