@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2010-2013  Tetsuo Handa <penguin-kernel@I-love.SAKURA.ne.jp>
  *
- * Version: 0.1.17   2016/09/28
+ * Version: 0.2   2016/10/05
  */
 
 #include "caitsith.h"
@@ -79,6 +79,7 @@ static union security_list_options original_cred_alloc_blank;
 static void cs_clear_execve(int ret, struct cs_security *security)
 {
 	struct cs_request_info *r;
+
 	if (security == &cs_default_security || security == &cs_oom_security)
 		return;
 	r = security->r;
@@ -136,6 +137,7 @@ static void cs_rcu_free(struct rcu_head *rcu)
 static void cs_del_security(struct cs_security *ptr)
 {
 	unsigned long flags;
+
 	if (ptr == &cs_default_security || ptr == &cs_oom_security)
 		return;
 	spin_lock_irqsave(&cs_task_security_list_lock, flags);
@@ -158,8 +160,7 @@ static void cs_add_cred_security(struct cs_security *ptr)
 		[hash_ptr((void *) ptr->cred, CS_TASK_SECURITY_HASH_BITS)];
 #ifdef CONFIG_CAITSITH_DEBUG
 	if (ptr->pid)
-		printk(KERN_INFO "CAITSITH: \"struct cs_security\"->pid != NULL"
-		       "\n");
+		printk(KERN_INFO "CAITSITH: \"struct cs_security\"->pid != NULL\n");
 #endif
 	ptr->pid = NULL;
 	spin_lock_irqsave(&cs_task_security_list_lock, flags);
@@ -179,6 +180,7 @@ static int cs_task_create(unsigned long clone_flags)
 	struct cs_security *old_security;
 	struct cs_security *new_security;
 	struct cred *cred = prepare_creds();
+
 	if (!cred)
 		return -ENOMEM;
 	old_security = cs_find_task_security(current);
@@ -266,6 +268,7 @@ static int cs_alloc_cred_security(const struct cred *cred, gfp_t gfp)
 static int cs_cred_alloc_blank(struct cred *new, gfp_t gfp)
 {
 	const int rc1 = cs_alloc_cred_security(new, gfp);
+
 	if (original_cred_alloc_blank.cred_alloc_blank) {
 		const int rc2 = original_cred_alloc_blank.
 			cred_alloc_blank(new, gfp);
@@ -289,6 +292,7 @@ static void cs_cred_transfer(struct cred *new, const struct cred *old)
 {
 	struct cs_security *new_security = cs_find_cred_security(new);
 	struct cs_security *old_security = cs_find_cred_security(old);
+
 	if (new_security == &cs_default_security ||
 	    new_security == &cs_oom_security ||
 	    old_security == &cs_default_security ||
@@ -309,6 +313,7 @@ static void cs_bprm_committing_creds(struct linux_binprm *bprm)
 {
 	struct cs_security *old_security = cs_current_security();
 	struct cs_security *new_security;
+
 	if (old_security == &cs_default_security ||
 	    old_security == &cs_oom_security)
 		return;
@@ -329,6 +334,7 @@ static void cs_bprm_committing_creds(struct linux_binprm *bprm)
 static _Bool cs_policy_loader_exists(void)
 {
 	struct path path;
+
 	if (kern_path(CONFIG_CAITSITH_POLICY_LOADER, LOOKUP_FOLLOW, &path)
 	    == 0) {
 		path_put(&path);
@@ -350,11 +356,12 @@ static _Bool cs_policy_loader_exists(void)
  * invoke /sbin/caitsith-init and wait for the termination of
  * /sbin/caitsith-init and then continues invocation of /sbin/init.
  * /sbin/caitsith-init reads policy files in /etc/caitsith/ directory and
- * writes to /proc/caitsith/ interfaces.
+ * writes to /sys/kernel/security/caitsith/ interfaces.
  */
 static void cs_load_policy(const char *filename)
 {
 	static _Bool done;
+
 	if (done)
 		return;
 	if (strcmp(filename, CONFIG_CAITSITH_ACTIVATION_TRIGGER))
@@ -365,6 +372,7 @@ static void cs_load_policy(const char *filename)
 	{
 		char *argv[2];
 		char *envp[3];
+
 		printk(KERN_INFO "Calling %s to load policy. Please wait.\n",
 		       CONFIG_CAITSITH_POLICY_LOADER);
 		argv[0] = (char *) CONFIG_CAITSITH_POLICY_LOADER;
@@ -390,6 +398,7 @@ static int cs_bprm_check_security(struct linux_binprm *bprm)
 {
 	struct cs_security *security = cs_current_security();
 	int rc;
+
 	if (security == &cs_default_security || security == &cs_oom_security)
 		return -ENOMEM;
 	if (security->r)
@@ -484,6 +493,7 @@ static int cs_inode_setattr(struct dentry *dentry, struct iattr *attr)
 {
 	int rc = 0;
 	struct path path = { .mnt = NULL, .dentry = dentry };
+
 	if (attr->ia_valid & ATTR_UID)
 		rc = cs_chown_permission(&path, attr->ia_uid, INVALID_GID);
 	if (!rc && (attr->ia_valid & ATTR_GID))
@@ -525,6 +535,7 @@ static int cs_path_mknod(const struct path *dir, struct dentry *dentry,
 			 umode_t mode, unsigned int dev)
 {
 	struct path path = { .mnt = dir->mnt, .dentry = dentry };
+
 	return cs_mknod_permission(&path, mode, dev);
 }
 
@@ -541,6 +552,7 @@ static int cs_path_mkdir(const struct path *dir, struct dentry *dentry,
 			 umode_t mode)
 {
 	struct path path = { .mnt = dir->mnt, .dentry = dentry };
+
 	return cs_mkdir_permission(&path, mode);
 }
 
@@ -555,6 +567,7 @@ static int cs_path_mkdir(const struct path *dir, struct dentry *dentry,
 static int cs_path_rmdir(const struct path *dir, struct dentry *dentry)
 {
 	struct path path = { .mnt = dir->mnt, .dentry = dentry };
+
 	return cs_rmdir_permission(&path);
 }
 
@@ -569,6 +582,7 @@ static int cs_path_rmdir(const struct path *dir, struct dentry *dentry)
 static int cs_path_unlink(const struct path *dir, struct dentry *dentry)
 {
 	struct path path = { .mnt = dir->mnt, .dentry = dentry };
+
 	return cs_unlink_permission(&path);
 }
 
@@ -585,6 +599,7 @@ static int cs_path_symlink(const struct path *dir, struct dentry *dentry,
 			   const char *old_name)
 {
 	struct path path = { .mnt = dir->mnt, .dentry = dentry };
+
 	return cs_symlink_permission(&path, old_name);
 }
 
@@ -605,6 +620,7 @@ static int cs_path_rename(const struct path *old_dir,
 {
 	struct path old = { .mnt = old_dir->mnt, .dentry = old_dentry };
 	struct path new = { .mnt = new_dir->mnt, .dentry = new_dentry };
+
 	return cs_rename_permission(&old, &new);
 }
 
@@ -622,6 +638,7 @@ static int cs_path_link(struct dentry *old_dentry, const struct path *new_dir,
 {
 	struct path old = { .mnt = new_dir->mnt, .dentry = old_dentry };
 	struct path new = { .mnt = new_dir->mnt, .dentry = new_dentry };
+
 	return cs_link_permission(&old, &new);
 }
 
@@ -641,6 +658,7 @@ static int cs_inode_mknod(struct inode *dir, struct dentry *dentry,
 			  umode_t mode, dev_t dev)
 {
 	struct path path = { .mnt = NULL, .dentry = dentry };
+
 	return cs_mknod_permission(&path, mode, dev);
 }
 
@@ -657,6 +675,7 @@ static int cs_inode_mkdir(struct inode *dir, struct dentry *dentry,
 			  umode_t mode)
 {
 	struct path path = { .mnt = NULL, .dentry = dentry };
+
 	return cs_mkdir_permission(&path, mode);
 }
 
@@ -671,6 +690,7 @@ static int cs_inode_mkdir(struct inode *dir, struct dentry *dentry,
 static int cs_inode_rmdir(struct inode *dir, struct dentry *dentry)
 {
 	struct path path = { .mnt = NULL, .dentry = dentry };
+
 	return cs_rmdir_permission(&path);
 }
 
@@ -685,6 +705,7 @@ static int cs_inode_rmdir(struct inode *dir, struct dentry *dentry)
 static int cs_inode_unlink(struct inode *dir, struct dentry *dentry)
 {
 	struct path path = { .mnt = NULL, .dentry = dentry };
+
 	return cs_unlink_permission(&path);
 }
 
@@ -701,6 +722,7 @@ static int cs_inode_symlink(struct inode *dir, struct dentry *dentry,
 			    const char *old_name)
 {
 	struct path path = { .mnt = NULL, .dentry = dentry };
+
 	return cs_symlink_permission(&path, old_name);
 }
 
@@ -719,6 +741,7 @@ static int cs_inode_rename(struct inode *old_dir, struct dentry *old_dentry,
 {
 	struct path old = { .mnt = NULL, .dentry = old_dentry };
 	struct path new = { .mnt = NULL, .dentry = new_dentry };
+
 	return cs_rename_permission(&old, &new);
 }
 
@@ -736,6 +759,7 @@ static int cs_inode_link(struct dentry *old_dentry, struct inode *dir,
 {
 	struct path old = { .mnt = NULL, .dentry = old_dentry };
 	struct path new = { .mnt = NULL, .dentry = new_dentry };
+
 	return cs_link_permission(&old, &new);
 }
 
@@ -752,6 +776,7 @@ static int cs_inode_create(struct inode *dir, struct dentry *dentry,
 			   umode_t mode)
 {
 	struct path path = { .mnt = NULL, .dentry = dentry };
+
 	return cs_mknod_permission(&path, mode, 0);
 }
 
@@ -789,6 +814,7 @@ static DEFINE_SPINLOCK(cs_accepted_socket_list_lock);
 static void cs_socket_rcu_free(struct rcu_head *rcu)
 {
 	struct cs_socket_tag *ptr = container_of(rcu, typeof(*ptr), rcu);
+
 	kfree(ptr);
 }
 
@@ -838,6 +864,7 @@ static int cs_validate_socket(struct socket *sock)
 	struct inode *inode = SOCK_INODE(sock);
 	struct cs_socket_tag *ptr;
 	int ret = 0;
+
 	rcu_read_lock();
 	list_for_each_entry_rcu(ptr, &cs_accepted_socket_list, list) {
 		if (ptr->inode != inode)
@@ -896,6 +923,7 @@ static int cs_socket_accept(struct socket *sock, struct socket *newsock)
 {
 	struct cs_socket_tag *ptr;
 	const int rc = cs_validate_socket(sock);
+
 	if (rc < 0)
 		return rc;
 	ptr = kzalloc(sizeof(*ptr), GFP_KERNEL);
@@ -926,6 +954,7 @@ static int cs_socket_accept(struct socket *sock, struct socket *newsock)
 static int cs_socket_listen(struct socket *sock, int backlog)
 {
 	const int rc = cs_validate_socket(sock);
+
 	if (rc < 0)
 		return rc;
 	return cs_socket_listen_permission(sock);
@@ -944,6 +973,7 @@ static int cs_socket_connect(struct socket *sock, struct sockaddr *addr,
 			     int addr_len)
 {
 	const int rc = cs_validate_socket(sock);
+
 	if (rc < 0)
 		return rc;
 	return cs_socket_connect_permission(sock, addr, addr_len);
@@ -962,6 +992,7 @@ static int cs_socket_bind(struct socket *sock, struct sockaddr *addr,
 			  int addr_len)
 {
 	const int rc = cs_validate_socket(sock);
+
 	if (rc < 0)
 		return rc;
 	return cs_socket_bind_permission(sock, addr, addr_len);
@@ -980,6 +1011,7 @@ static int cs_socket_sendmsg(struct socket *sock, struct msghdr *msg,
 			     int size)
 {
 	const int rc = cs_validate_socket(sock);
+
 	if (rc < 0)
 		return rc;
 	return cs_socket_sendmsg_permission(sock, msg, size);
@@ -1127,6 +1159,7 @@ static int cs_sb_mount(const char *dev_name, const struct path *path,
 static int cs_sb_umount(struct vfsmount *mnt, int flags)
 {
 	struct path path = { .mnt = mnt, .dentry = mnt->mnt_root };
+
 	return cs_umount_permission(&path, flags);
 }
 
@@ -1230,6 +1263,7 @@ static void __init swap_hook(struct security_hook_list *hook,
 			     union security_list_options *original)
 {
 	struct list_head *list = hook->head;
+
 	if (list_empty(list)) {
 		add_hook(hook);
 	} else {
@@ -1250,6 +1284,7 @@ static int __init cs_init(void)
 {
 	int idx;
 	struct security_hook_heads *hooks = probe_security_hook_heads();
+
 	if (!hooks)
 		goto out;
 	for (idx = 0; idx < ARRAY_SIZE(caitsith_hooks); idx++)
@@ -1296,10 +1331,13 @@ bool cs_used_by_cred(const struct cs_domain_info *domain)
 {
 	int idx;
 	struct cs_security *ptr;
+
 	for (idx = 0; idx < CS_MAX_TASK_SECURITY_HASH; idx++) {
 		struct list_head *list = &cs_cred_security_list[idx];
+
 		list_for_each_entry_rcu(ptr, list, list) {
 			struct cs_request_info *r = ptr->r;
+
 			if (ptr->cs_domain_info == domain ||
 			    (r && r->previous_domain == domain)) {
 				return true;
@@ -1321,6 +1359,7 @@ static void cs_add_task_security(struct cs_security *ptr,
 				 struct list_head *list)
 {
 	unsigned long flags;
+
 	spin_lock_irqsave(&cs_task_security_list_lock, flags);
 	list_add_rcu(&ptr->list, list);
 	spin_unlock_irqrestore(&cs_task_security_list_lock, flags);
@@ -1345,7 +1384,8 @@ struct cs_security *cs_find_task_security(const struct task_struct *task)
 	struct list_head *list = &cs_task_security_list
 		[hash_ptr((void *) task, CS_TASK_SECURITY_HASH_BITS)];
 	/* Make sure INIT_LIST_HEAD() in cs_mm_init() takes effect. */
-	while (!list->next);
+	while (!list->next)
+		;
 	rcu_read_lock();
 	list_for_each_entry_rcu(ptr, list, list) {
 		if (ptr->pid != task->pids[PIDTYPE_PID].pid)
@@ -1500,6 +1540,7 @@ static void cs_task_security_gc(void)
 	for (idx = 0; idx < CS_MAX_TASK_SECURITY_HASH; idx++) {
 		struct cs_security *ptr;
 		struct list_head *list = &cs_task_security_list[idx];
+
 		list_for_each_entry_rcu(ptr, list, list) {
 			if (pid_task(ptr->pid, PIDTYPE_PID))
 				continue;
