@@ -783,7 +783,11 @@ bool cs_dump_page(struct linux_binprm *bprm, unsigned long pos,
 	}
 	/* Same with get_arg_page(bprm, pos, 0) in fs/exec.c */
 #ifdef CONFIG_MMU
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 6, 0)
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 9, 0)
+	if (get_user_pages_remote(current, bprm->mm, pos, 1, FOLL_FORCE, &page,
+				  NULL) <= 0)
+		return false;
+#elif LINUX_VERSION_CODE >= KERNEL_VERSION(4, 6, 0)
 	if (get_user_pages_remote(current, bprm->mm, pos, 1, 0, 1, &page,
 				  NULL) <= 0)
 		return false;
