@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.1.17   2016/09/28
+ * Version: 0.2   2016/10/05
  */
 
 #include "caitsith.h"
@@ -184,10 +184,12 @@ static char *cs_get_absolute_path(const struct path *path, char * const buffer,
 	 */
 	static bool cs_no_empty;
 	char *pos;
+
 	if (buflen < 256)
 		return ERR_PTR(-ENOMEM);
 	if (!cs_no_empty) {
 		struct path root = { };
+
 		pos = caitsith_exports.__d_path(path, &root, buffer,
 						buflen - 1);
 	} else {
@@ -197,6 +199,7 @@ static char *cs_get_absolute_path(const struct path *path, char * const buffer,
 		struct task_struct *task = current;
 		struct path root;
 		struct path tmp;
+
 		spin_lock(&task->fs->lock);
 		root.mnt = task->nsproxy->mnt_ns->root;
 		root.dentry = root.mnt->mnt_root;
@@ -226,6 +229,7 @@ static char *cs_get_absolute_path(const struct path *path, char * const buffer,
 	*pos = '\0';
 	for (;;) {
 		struct dentry *parent;
+
 		if (dentry == vfsmnt->mnt_root || IS_ROOT(dentry)) {
 			if (vfsmnt->mnt_parent == vfsmnt)
 				break;
@@ -277,6 +281,7 @@ static char *cs_get_dentry_path(struct dentry *dentry, char * const buffer,
 	return dentry_path_raw(dentry, buffer, buflen - 1);
 #else
 	char *pos = buffer + buflen - 1;
+
 	if (buflen < 256)
 		return ERR_PTR(-ENOMEM);
 	*pos = '\0';
@@ -285,6 +290,7 @@ static char *cs_get_dentry_path(struct dentry *dentry, char * const buffer,
 		struct dentry *parent = dentry->d_parent;
 		const char *name = dentry->d_name.name;
 		const int len = dentry->d_name.len;
+
 		pos -= len;
 		if (pos <= buffer) {
 			pos = ERR_PTR(-ENOMEM);
@@ -315,12 +321,14 @@ static char *cs_get_local_path(struct dentry *dentry, char * const buffer,
 {
 	struct super_block *sb = dentry->d_sb;
 	char *pos = cs_get_dentry_path(dentry, buffer, buflen);
+
 	if (IS_ERR(pos))
 		return pos;
 	/* Convert from $PID to self if $PID is current thread. */
 	if (sb->s_magic == PROC_SUPER_MAGIC && *pos == '/') {
 		char *ep;
 		const pid_t pid = (pid_t) simple_strtoul(pos + 1, &ep, 10);
+
 		if (*ep == '/' && pid && pid ==
 		    task_tgid_nr_ns(current, sb->s_fs_info)) {
 			pos = ep - 5;
@@ -335,6 +343,7 @@ static char *cs_get_local_path(struct dentry *dentry, char * const buffer,
 		goto prepend_filesystem_name;
 	{
 		struct inode *inode = d_backing_inode(sb->s_root);
+
 		/*
 		 * Use filesystem name if filesystems does not support rename()
 		 * operation.
@@ -355,6 +364,7 @@ static char *cs_get_local_path(struct dentry *dentry, char * const buffer,
 		char name[64];
 		int name_len;
 		const dev_t dev = sb->s_dev;
+
 		name[sizeof(name) - 1] = '\0';
 		snprintf(name, sizeof(name) - 1, "dev(%u,%u):", MAJOR(dev),
 			 MINOR(dev));
@@ -370,6 +380,7 @@ prepend_filesystem_name:
 	{
 		const char *name = sb->s_type->name;
 		const int name_len = strlen(name);
+
 		pos -= name_len + 1;
 		if (pos < buffer)
 			goto out;
@@ -396,10 +407,11 @@ static char *cs_get_socket_name(const struct path *path, char * const buffer,
 	struct inode *inode = d_backing_inode(path->dentry);
 	struct socket *sock = inode ? SOCKET_I(inode) : NULL;
 	struct sock *sk = sock ? sock->sk : NULL;
+
 	if (sk) {
-		snprintf(buffer, buflen, "socket:[family=%u:type=%u:"
-			 "protocol=%u]", sk->sk_family, sk->sk_type,
-			 sk->sk_protocol);
+		snprintf(buffer, buflen,
+			 "socket:[family=%u:type=%u:protocol=%u]",
+			 sk->sk_family, sk->sk_type, sk->sk_protocol);
 	} else {
 		snprintf(buffer, buflen, "socket:[unknown]");
 	}
@@ -423,12 +435,14 @@ char *cs_realpath(const struct path *path)
 	unsigned int buf_len = PAGE_SIZE / 2;
 	struct dentry *dentry = path->dentry;
 	struct super_block *sb;
+
 	if (!dentry)
 		return NULL;
 	sb = dentry->d_sb;
 	while (1) {
 		char *pos;
 		struct inode *inode;
+
 		buf_len <<= 1;
 		kfree(buf);
 		buf = kmalloc(buf_len, GFP_NOFS);
@@ -506,11 +520,13 @@ char *cs_encode2(const char *str, int str_len)
 	const char *p = str;
 	char *cp;
 	char *cp0;
+
 	if (!p)
 		return NULL;
 	len = str_len;
 	for (i = 0; i < str_len; i++) {
 		const unsigned char c = p[i];
+
 		if (!(c > ' ' && c < 127 && c != '\\'))
 			len += 3;
 	}
@@ -522,6 +538,7 @@ char *cs_encode2(const char *str, int str_len)
 	p = str;
 	for (i = 0; i < str_len; i++) {
 		const unsigned char c = p[i];
+
 		if (c > ' ' && c < 127 && c != '\\') {
 			*cp++ = c;
 		} else {
@@ -560,6 +577,7 @@ static int cs_const_part_length(const char *filename)
 {
 	char c;
 	int len = 0;
+
 	if (!filename)
 		return 0;
 	while (1) {
@@ -603,6 +621,7 @@ void cs_fill_path_info(struct cs_path_info *ptr)
 {
 	const char *name = ptr->name;
 	const int len = strlen(name);
+
 	ptr->total_len = len;
 	ptr->const_len = cs_const_part_length(name);
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 8, 0)
@@ -627,6 +646,7 @@ char *cs_get_exe(void)
 	struct vm_area_struct *vma;
 #endif
 	struct file *exe_file;
+
 	if (current->flags & PF_KTHREAD)
 		return kstrdup("<kernel>", GFP_NOFS);
 	mm = current->mm;
@@ -650,6 +670,7 @@ char *cs_get_exe(void)
 	up_read(&mm->mmap_sem);
 	if (exe_file) {
 		char *cp = cs_realpath(&exe_file->f_path);
+
 		fput(exe_file);
 		return cp;
 	}
